% This file is part of the OPTPDE problem collection
%                 http://www.optpde.net
% It is provided as is, without any warranty, under the 
%
% Creative Commons Attribution-NonCommercial ShareAlike 4.0 International
%
%         http://creativecommons.org/licenses/by-nc-sa/4.0/
%
% Please give proper credits when using this file by referencing the 
% collection. For this purpose detailed bibliography data is 
% available at the collections website 
%                  
%                 http://www.optpde.net
%
% This file contains data for the benchmark problem 
%                      mpccdist3
% from  2022-04-01 


% setup the problem
problem = setup_problem;

% generate a grid on the domain
[r,phi] = meshgrid(linspace(0,1,40),linspace(0,2*pi,41));
[x1,x2] = pol2cart(phi,r);

% plot the (stationary) desired control for cases 1-3
figure(1); clf; hold on
val = ld(problem,x1,x2,0);
surf(x1,x2,val);
xlabel('x_1');
ylabel('x_2');
title('desired control l_d (stationary)');
view(3);

% plot the (stationary) desired displacement for cases 1-3
figure(2); clf; hold on
val = ud(problem,x1,x2,0);
surf(x1,x2,val);
xlabel('x_1');
ylabel('x_2');
title('desired displacement u_d (stationary)');
view(3);

% plot the (stationary) desired nonlocal damage variable (case 1)
figure(3); clf; hold on
val = phid_case1(problem,x1,x2,0);
surf(x1,x2,val);
xlabel('x_1');
ylabel('x_2');
title('desired nonlocal damage variable \phi_d (case 1, stationary)');
view(3);

% plot the (stationary) desired nonlocal damage variable (case 2)
figure(4); clf; hold on
val = phid_case2(problem,x1,x2,0);
surf(x1,x2,val);
xlabel('x_1');
ylabel('x_2');
title('desired nonlocal damage variable \phi_d (case 2, stationary)');
view(3);

% plot the (stationary) desired nonlocal damage variable (case 3)
figure(5); clf; hold on
val = phid_case3(problem,x1,x2,0);
surf(x1,x2,val);
xlabel('x_1');
ylabel('x_2');
title('desired nonlocal damage variable \phi_d (case 3, stationary)');
view(3);

% plot the (stationary) desired local damage variable (case 1)
figure(6); clf; hold on
val = dd_case1(problem,x1,x2,0);
surf(x1,x2,val);
xlabel('x_1');
ylabel('x_2');
title('desired local damage variable d_d (case 1, stationary)');
view(3);

% plot the (non-stationary) desired local damage variable (case 2) at time t = 0
figure(7); clf; hold on
val = dd_case2(problem,x1,x2,0);
surf(x1,x2,val);
xlabel('x_1');
ylabel('x_2');
title('desired local damage variable d_d (case 2, time t = 0)');
view(3);

% plot the (stationary) desired local damage variable (case 3)
figure(8); clf; hold on
val = dd_case3(problem,x1,x2,0);
surf(x1,x2,val);
xlabel('x_1');
ylabel('x_2');
title('desired local damage variable d_d (case 3, stationary)');
view(3);

% plot the (stationary) auxiliary data function e1 (case 1)
figure(9); clf; hold on
val = e1_case1(problem,x1,x2,0);
surf(x1,x2,val);
xlabel('x_1');
ylabel('x_2');
title('auxiliary data function e_1 (case 1, stationary)');
view(3);

% plot the (non-stationary) auxiliary data function e1 (case 2) at time t = 0
figure(10); clf; hold on
val = e1_case2(problem,x1,x2,0);
surf(x1,x2,val);
xlabel('x_1');
ylabel('x_2');
title('auxiliary data function e_1 (case 2, time t = 0)');
view(3);

% plot the (stationary) auxiliary data function e1 (case 3)
figure(11); clf; hold on
val = e1_case3(problem,x1,x2,0);
surf(x1,x2,val);
xlabel('x_1');
ylabel('x_2');
title('auxiliary data function e_1 (case 3, stationary)');
view(3);

% plot the (stationary) auxiliary data function e2 (case 1)
figure(12); clf; hold on
val = e2_case1(problem,x1,x2,0);
surf(x1,x2,val);
xlabel('x_1');
ylabel('x_2');
title('auxiliary data function e_2 (case 1, stationary)');
view(3);

% plot the (non-stationary) auxiliary data function e2 (case 2) at time t = 0
figure(13); clf; hold on
val = e2_case2(problem,x1,x2,0);
surf(x1,x2,val);
xlabel('x_1');
ylabel('x_2');
title('auxiliary data function e_2 (case 2, time t = 0)');
view(3);

% plot the (stationary) auxiliary data function e2 (case 3)
figure(14); clf; hold on
val = e2_case3(problem,x1,x2,0);
surf(x1,x2,val);
xlabel('x_1');
ylabel('x_2');
title('auxiliary data function e_2 (case 3, stationary)');
view(3);

% plot the (stationary) auxiliary data function d0 (case 1)
figure(15); clf; hold on
val = d0_case1(problem,x1,x2);
surf(x1,x2,val);
xlabel('x_1');
ylabel('x_2');
title('auxiliary data function d_0 (case 1, stationary)');
view(3);

% plot the (stationary) auxiliary data function d0 (case 2)
figure(16); clf; hold on
val = d0_case2(problem,x1,x2);
surf(x1,x2,val);
xlabel('x_1');
ylabel('x_2');
title('auxiliary data function d_0 (case 2, stationary)');
view(3);

% plot the (stationary) auxiliary data function d0 (case 3)
figure(17); clf; hold on
val = d0_case3(problem,x1,x2);
surf(x1,x2,val);
xlabel('x_1');
ylabel('x_2');
title('auxiliary data function d_0 (case 3, stationary)');
view(3);

% show the (stationary) inactive region (case 1)
figure(18); clf; hold on
val = double(- problem.beta * (supplementary_d_case1(problem,x1,x2,0) - supplementary_phi_case1(problem,x1,x2,0)) - problem.r < 0);
surf(x1,x2,val);
xlabel('x_1');
ylabel('x_2');
title('inactive points (case 1, stationary)');
view(2);
axis equal
colorbar

% show the (non-stationary) strongly active region (case 2)
figure(19); clf; hold on
val = double(- problem.beta * (supplementary_d_case2(problem,x1,x2,0) - supplementary_phi_case2(problem,x1,x2,0)) - problem.r > 0);
surf(x1,x2,val);
xlabel('x_1');
ylabel('x_2');
title('strongly active points (case 2, time t = 0)');
view(2);
axis equal
colorbar

% show the (stationary) biactive region (case 3)
figure(20); clf; hold on
val = double(abs(- problem.beta * (supplementary_d_case3(problem,x1,x2,0) - supplementary_phi_case3(problem,x1,x2,0)) - problem.r) < 1e-12);
surf(x1,x2,val);
xlabel('x_1');
ylabel('x_2');
title('biactive points (case 3, stationary)');
view(2);
axis equal
colorbar

